==> vault-debug-1.15.1-1-x86_64.pkg.tar.zst: usr/src/debug/vault/pkg/mod/github.com/microsoftgraph/msgraph-sdk-go@v1.13.0/models/learning_self_initiated_course.go <==
package models

import (
    i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e "time"
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization"
)

// LearningSelfInitiatedCourse 
type LearningSelfInitiatedCourse struct {
    LearningCourseActivity
}
// NewLearningSelfInitiatedCourse instantiates a new learningSelfInitiatedCourse and sets the default values.
func NewLearningSelfInitiatedCourse()(*LearningSelfInitiatedCourse) {
    m := &LearningSelfInitiatedCourse{
        LearningCourseActivity: *NewLearningCourseActivity(),
    }
    return m
}
// CreateLearningSelfInitiatedCourseFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value
func CreateLearningSelfInitiatedCourseFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error) {
    return NewLearningSelfInitiatedCourse(), nil
}
// GetFieldDeserializers the deserialization information for the current model
func (m *LearningSelfInitiatedCourse) GetFieldDeserializers()(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error)) {
    res := m.LearningCourseActivity.GetFieldDeserializers()
    res["startedDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetStartedDateTime(val)
        }
        return nil
    }
    return res
}
// GetStartedDateTime gets the startedDateTime property value. The date time value on which the self-initiated course was started by the learner. Optional.
func (m *LearningSelfInitiatedCourse) GetStartedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    val, err := m.GetBackingStore().Get("startedDateTime")
    if err != nil {
        panic(err)
    }
    if val != nil {
        return val.(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)
    }
    return nil
}
// Serialize serializes information the current object
func (m *LearningSelfInitiatedCourse) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter)(error) {
    err := m.LearningCourseActivity.Serialize(writer)
    if err != nil {
        return err
    }
    {
        err = writer.WriteTimeValue("startedDateTime", m.GetStartedDateTime())
        if err != nil {
            return err
        }
    }
    return nil
}
// SetStartedDateTime sets the startedDateTime property value. The date time value on which the self-initiated course was started by the learner. Optional.
func (m *LearningSelfInitiatedCourse) SetStartedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    err := m.GetBackingStore().Set("startedDateTime", value)
    if err != nil {
        panic(err)
    }
}
// LearningSelfInitiatedCourseable 
type LearningSelfInitiatedCourseable interface {
    LearningCourseActivityable
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
    GetStartedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)
    SetStartedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)()
}

==> vault-debug-1.16.2-1-x86_64.pkg.tar.zst: usr/src/debug/vault/pkg/mod/github.com/microsoftgraph/msgraph-sdk-go@v1.32.0/models/learning_self_initiated_course.go <==
package models

import (
    i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e "time"
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91 "github.com/microsoft/kiota-abstractions-go/serialization"
)

// LearningSelfInitiatedCourse 
type LearningSelfInitiatedCourse struct {
    LearningCourseActivity
}
// NewLearningSelfInitiatedCourse instantiates a new learningSelfInitiatedCourse and sets the default values.
func NewLearningSelfInitiatedCourse()(*LearningSelfInitiatedCourse) {
    m := &LearningSelfInitiatedCourse{
        LearningCourseActivity: *NewLearningCourseActivity(),
    }
    return m
}
// CreateLearningSelfInitiatedCourseFromDiscriminatorValue creates a new instance of the appropriate class based on discriminator value
func CreateLearningSelfInitiatedCourseFromDiscriminatorValue(parseNode i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable, error) {
    return NewLearningSelfInitiatedCourse(), nil
}
// GetFieldDeserializers the deserialization information for the current model
func (m *LearningSelfInitiatedCourse) GetFieldDeserializers()(map[string]func(i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode)(error)) {
    res := m.LearningCourseActivity.GetFieldDeserializers()
    res["startedDateTime"] = func (n i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.ParseNode) error {
        val, err := n.GetTimeValue()
        if err != nil {
            return err
        }
        if val != nil {
            m.SetStartedDateTime(val)
        }
        return nil
    }
    return res
}
// GetStartedDateTime gets the startedDateTime property value. The date and time on which the learner started the self-initiated course. Optional.
func (m *LearningSelfInitiatedCourse) GetStartedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time) {
    val, err := m.GetBackingStore().Get("startedDateTime")
    if err != nil {
        panic(err)
    }
    if val != nil {
        return val.(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)
    }
    return nil
}
// Serialize serializes information the current object
func (m *LearningSelfInitiatedCourse) Serialize(writer i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.SerializationWriter)(error) {
    err := m.LearningCourseActivity.Serialize(writer)
    if err != nil {
        return err
    }
    {
        err = writer.WriteTimeValue("startedDateTime", m.GetStartedDateTime())
        if err != nil {
            return err
        }
    }
    return nil
}
// SetStartedDateTime sets the startedDateTime property value. The date and time on which the learner started the self-initiated course. Optional.
func (m *LearningSelfInitiatedCourse) SetStartedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)() {
    err := m.GetBackingStore().Set("startedDateTime", value)
    if err != nil {
        panic(err)
    }
}
// LearningSelfInitiatedCourseable 
type LearningSelfInitiatedCourseable interface {
    LearningCourseActivityable
    i878a80d2330e89d26896388a3f487eef27b0a0e6c010c493bf80be1452208f91.Parsable
    GetStartedDateTime()(*i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)
    SetStartedDateTime(value *i336074805fc853987abe6f7fe3ad97a6a6f3077a16391fec744f671a015fbd7e.Time)()
}
